==> jmb.price-0.2.tar.gz: jmb.price-0.2/jmb/price/admin.py <==
# -*- coding: utf-8 -*-
from django.conf import settings
from django.utils.translation import ugettext as _
from django.utils.translation import ugettext_lazy as ugt
from django.contrib import admin

from jmb.core.admin.options import ExtendibleModelAdmin

from jmb.price.models import PriceList, PriceListItem, OrganizationPriceList

class PriceListAdmin(ExtendibleModelAdmin):
    fieldsets = (
        (_('logs admin'), {'fields': (
            'creator', 'date_create',
            'last_modifier', 'date_last_modify',
        ), 'classes': ('collapse',)}),
        (_('visualization admin'), {'fields': ('ordering',), 'classes': ('collapse',),}),
        (_('general admin'), {'fields': ('status', 'name', 'slug', 'code', 'pricelist_type', 'currency'),}),
        (_('time admin'), {'fields': (('date_begin', 'date_end',),),}),
    )
    list_display = (
        'get_status_icon', 'code', 'name',
        'date_begin', 'date_end', 'ordering',
        'get_edit_icon', 'get_delete_icon'
    )
    search_fields = ('name', 'code')
    prepopulated_fields = {"slug": ("name",)}

class PriceListItemAdmin(ExtendibleModelAdmin):
    fieldsets = (
        (_('logs admin'), {'fields': (
            'creator', 'date_create',
            'last_modifier', 'date_last_modify',
        ), 'classes': ('collapse',)}),
        (_('visualization admin'), {'fields': ('ordering',), 'classes': ('collapse',),}),
        (_('general admin'), {'fields': (
            'status', 'price_list', 'product', 'price',
            'vat', 'price_tax_included',
            'discount1', 'discount2', 'recharge',
            'min_quantity', 'max_quantity',
        ),}),
        (_('time admin'), {'fields': (('date_begin','date_end',),),}),
        )
    list_display = (
        'get_status_icon', 'get_price_list', 'product', 'get_date_begin',
        'get_date_end', 'price', 'vat', 'price_tax_included',
        'discount1', 'discount2', 'recharge',
        'min_quantity', 'max_quantity',
        'get_edit_icon', 'get_delete_icon'
    )
    list_display_csv = (
        'status', 'get_price_list_csv', 'product', 'get_date_begin',
        'get_date_end', 'price', 'vat', 'price_tax_included',
        'discount1', 'discount2', 'recharge',
        'min_quantity', 'max_quantity'
    )
    search_fields = ('product__name', 'product__code')

    def get_price_list_csv(self, obj):
        return "%s - %s" % (
            obj.price_list.code, obj.price_list.name
            )
    get_price_list_csv.short_description = ugt("Price List")

    def get_price_list(self, obj):
        return "%s<br/><b>%s</b><br/>%s - %s" % (
            obj.price_list.code, obj.price_list.name,
            obj.price_list.date_begin, obj.price_list.date_end
        )
    get_price_list.short_description = ugt("Price List")
    get_price_list.admin_order_field = 'price_list.name'
    get_price_list.allow_tags = True

class OrganizationPriceListAdmin(ExtendibleModelAdmin):
    fieldsets = (
        (_('logs admin'), {'fields': (
            'creator', 'date_create',
            'last_modifier', 'date_last_modify',
        ), 'classes': ('collapse',)}),
        (_('general admin'), {'fields': (
            'status', 'price_list', 'organization',
            ('discount1', 'discount2', 'recharge'),
        ),}),
    )
    search_fields = ('organization__code', 'organization__name',)
    list_display = (
        'get_status_icon', 'get_organization_code', 'get_organization_name',
        'get_price_list_code', 'get_price_list_name', 'discount1', 'discount2', 'recharge',
        'get_edit_icon', 'get_delete_icon'
    )


    def get_organization_code(self, obj):
        return obj.organization.code
    get_organization_code.short_description = ugt("Organization Code")
    get_organization_code.admin_order_field = 'organization.code'
    get_organization_code.allow_tags = True


    def get_organization_name(self, obj):
        return obj.organization.name
    get_organization_name.short_description = ugt("Organization Name")
    get_organization_name.admin_order_field = 'organization.name'
    get_organization_name.allow_tags = True


    def get_price_list_code(self, obj):
        return obj.price_list.code
    get_price_list_code.short_description = ugt("Price List Code")
    get_price_list_code.admin_order_field = 'price_list.code'
    get_price_list_code.allow_tags = True


    def get_price_list_name(self, obj):
        return obj.price_list.name
    get_price_list_name.short_description = _("Price List Code")
    get_price_list_name.admin_order_field = 'price_list.name'
    get_price_list_name.allow_tags = True

admin.site.register(PriceList, PriceListAdmin)
admin.site.register(PriceListItem, PriceListItemAdmin)
admin.site.register(OrganizationPriceList, OrganizationPriceListAdmin)

==> jmb.price-0.3.1.tar.gz: jmb.price-0.3.1/jmb/price/admin.py <==
# -*- coding: utf-8 -*-

from django.conf import settings
from django.utils.translation import ugettext as _
from django.utils.translation import ugettext_lazy as ugt
from django.contrib import admin

from jmb.core.admin.options import ExtendibleModelAdmin

from jmb.price.models import PriceList, PriceListItem, OrganizationPriceList


class PriceListAdmin(ExtendibleModelAdmin):
    fieldsets = (
        (_('logs admin'), {'fields': (
            'creator', 'date_create',
            'last_modifier', 'date_last_modify',
        ), 'classes': ('collapse',)}),
        (_('visualization admin'), {'fields': ('ordering',), 'classes': ('collapse',)}),
        (_('general admin'), {'fields': ('status', 'name', 'slug', 'code', 'pricelist_type', 'currency')}),
        (_('time admin'), {'fields': (('date_begin', 'date_end',),)}),
    )
    list_display = (
        'get_status_icon', 'code', 'name',
        'date_begin', 'date_end', 'ordering',
        'get_edit_icon', 'get_delete_icon'
    )
    search_fields = ('name', 'code')
    prepopulated_fields = {"slug": ("name",)}


class PriceListItemAdmin(ExtendibleModelAdmin):
    fieldsets = (
        (_('logs admin'), {'fields': (
            'creator', 'date_create',
            'last_modifier', 'date_last_modify',
        ), 'classes': ('collapse',)}),
        (_('visualization admin'), {'fields': ('ordering',), 'classes': ('collapse',)}),
        (_('general admin'), {'fields': (
            'status', 'price_list', 'product', 'price',
            'vat', 'price_tax_included',
            'discount1', 'discount2', 'recharge',
            'min_quantity', 'max_quantity',
        )}),
        (_('time admin'), {'fields': (('date_begin', 'date_end',),)}),
    )
    list_display = (
        'get_status_icon', 'get_price_list', 'product', 'get_date_begin',
        'get_date_end', 'price', 'vat', 'price_tax_included',
        'discount1', 'discount2', 'recharge',
        'min_quantity', 'max_quantity',
        'get_edit_icon', 'get_delete_icon'
    )
    list_display_csv = (
        'status', 'get_price_list_csv', 'product', 'get_date_begin',
        'get_date_end', 'price', 'vat', 'price_tax_included',
        'discount1', 'discount2', 'recharge',
        'min_quantity', 'max_quantity'
    )
    search_fields = ('product__name', 'product__code')

    def get_price_list_csv(self, obj):
        return "%s - %s" % (
            obj.price_list.code, obj.price_list.name
        )
    get_price_list_csv.short_description = ugt("Price List")

    def get_price_list(self, obj):
        return "%s<br/><b>%s</b><br/>%s - %s" % (
            obj.price_list.code, obj.price_list.name,
            obj.price_list.date_begin, obj.price_list.date_end
        )
    get_price_list.short_description = ugt("Price List")
    get_price_list.admin_order_field = 'price_list.name'
    get_price_list.allow_tags = True


class OrganizationPriceListAdmin(ExtendibleModelAdmin):
    fieldsets = (
        (_('logs admin'), {'fields': (
            'creator', 'date_create',
            'last_modifier', 'date_last_modify',
        ), 'classes': ('collapse',)}),
        (_('general admin'), {'fields': (
            'status', 'price_list', 'organization',
            ('discount1', 'discount2', 'recharge'),
        )}),
    )
    search_fields = ('organization__code', 'organization__name',)
    list_display = (
        'get_status_icon', 'get_organization_code', 'get_organization_name',
        'get_price_list_code', 'get_price_list_name', 'discount1', 'discount2', 'recharge',
        'get_edit_icon', 'get_delete_icon'
    )

    def get_organization_code(self, obj):
        return obj.organization.code
    get_organization_code.short_description = ugt("Organization Code")
    get_organization_code.admin_order_field = 'organization.code'
    get_organization_code.allow_tags = True

    def get_organization_name(self, obj):
        return obj.organization.name
    get_organization_name.short_description = ugt("Organization Name")
    get_organization_name.admin_order_field = 'organization.name'
    get_organization_name.allow_tags = True

    def get_price_list_code(self, obj):
        return obj.price_list.code
    get_price_list_code.short_description = ugt("Price List Code")
    get_price_list_code.admin_order_field = 'price_list.code'
    get_price_list_code.allow_tags = True

    def get_price_list_name(self, obj):
        return obj.price_list.name
    get_price_list_name.short_description = _("Price List Name")
    get_price_list_name.admin_order_field = 'price_list.name'
    get_price_list_name.allow_tags = True

admin.site.register(PriceList, PriceListAdmin)
admin.site.register(PriceListItem, PriceListItemAdmin)
admin.site.register(OrganizationPriceList, OrganizationPriceListAdmin)
